package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````U!\```````!``````````*BQ````
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````)B>````````F)X`````````
M``$```````$````&````,*L````````PJP$``````#"K`0``````4`4`````
M``!X%0```````````0```````@````8```!`JP```````$"K`0``````0*L!
M```````P`@```````#`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````%)<````````4EP```````!27````````#`$````````,`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````#"K````````,*L!```````PJP$`
M`````-`$````````T`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`/+,%R&+]YF$#2U/1IGO\4^]S
MWT($````$`````$```!'3E4```````,````'`````````#T```!+````!```
M``@````A$!``!<`$A"@"$`6`AD"$@@D`!`D@!(B(H!!%N@`""```````````
M2P````````!,````30```$\`````````4`````````!1````4@```%,```!4
M`````````%4```!7`````````````````````````````````````````%@`
M``!9````6P```%T```````````````````!>`````````%\`````````8```
M`&$`````````8@```&,`````````9````&4`````````````````````````
M`````&8``````````````&<`````````:```````````````:0``````````
M``````````````"[XY)\:QJ>4"[%F[9#^M>'%8PES&>OS&9OQ=\?B0=PTZ/@
M^TG[H6Q@`*\TZ+_:5QO59-1\P^4_+'ZIG)NM2^/`XD?&`<_>1RT-%.*>(?_D
M#N&G`@K;S>.>6>^7>7=4/)2S`8MO#3J7"]EQ6!PS8MOM:PE#UD-%U>QK?YI\
M``````````````````````````````````````,`"P#('```````````````
M``````````,`%@``L`$`````````````````1`(``!(`````````````````
M````````NP(``!(`````````````````````````%`(``!(`````````````
M````````````&P(``!(`````````````````````````K0(``!(`````````
M````````````````O0$``!(``````````````````````````0```"``````
M````````````````````;`(``!(`````````````````````````A`(``!(`
M````````````````````````G@(``"(`````````````````````````?0(`
M`!(`````````````````````````9`(``!(`````````````````````````
M=@(``!$`````````````````````````EP```!(`````````````````````
M````[0(``!(`````````````````````````V````!(`````````````````
M````````%0$``!(`````````````````````````!@(``!(`````````````
M````````````*P$``!(`````````````````````````<P$``!$`````````
M````````````````2P(``!(`````````````````````````YP```!(`````
M````````````````````1@```!$`````````````````````````NP```!(`
M````````````````````````P@$``!(`````````````````````````T0(`
M`!(`````````````````````````(@(``!(`````````````````````````
M]0```!(`````````````````````````FP$``!(`````````````````````
M````'P$``!(`````````````````````````HP$``!(`````````````````
M````````\0$``!(`````````````````````````#0(``!(`````````````
M````````````R@$``!(`````````````````````````TP$``!(`````````
M````````````````MP$``!(`````````````````````````4P```!(`````
M````````````````````'0```"``````````````````````````_P(``!$`
M````````````````````````Y`(``"$`````````````````````````^0$`
M`!(`````````````````````````PP(``!(`````````````````````````
M,@$``!(`````````````````````````-@(``!(`````````````````````
M````R@(``!(`````````````````````````C0,``!(`````````````````
M````````,`(``!(`````````````````````````@````!(`````````````
M``````````````$``!(`````````````````````````C````!(`````````
M````````````````60(``!(`````````````````````````4@$``!(`````
M````````````````````&@$``!(`````````````````````````90$``!(`
M````````````````````````E`(``!(`````````````````````````8P``
M`!(`````````````````````````L````!(`````````````````````````
M00$``!(`````````````````````````C0(``!(`````````````````````
M````;P```!(`````````````````````````CP$``!(`````````````````
M````````_P$``!(`````````````````````````XP(``!$`````````````
M````````````Y0(``!$`````````````````````````E`$``!(`````````
M````````````````R0```!(`````````````````````````IP```!(`````
M````````````````````*0(``!(`````````````````````````+````"``
M````````````````````````?@$``!(`````````````````````````Y`$`
M`!(`````````````````````````ZP$``!(`````````````````````````
M,@0``!``%P"HP`$`````````````````3`0``!(`#0!@5````````*P!````
M````7`,``!(`#0!@*P````````0`````````VP,``!(`#0`P4P```````"@!
M````````EP0``!(`#0#04@```````%P`````````P@,``!(`#0`@+@``````
M`"0`````````E@,``!(`#0#@0````````&`!````````*`0``!$`%@!XL`$`
M``````@`````````/P0``!(`#0!$+@```````"@%````````=P0``!(`#0`P
M-````````$`!````````J@,``!``%P"HP`$`````````````````J0,``!``
M%P"HP`$`````````````````H`0``!(`#0#P/0```````.P"````````8@0`
M`!(`#0``*@```````$@`````````>P,``!(`#0``-````````#``````````
M\P,``!$`#P#`5@````````0`````````M0,``!(`#0#P+0```````"@`````
M````S@,``!(`#0!P-0```````(`(````````3`,``!(`#0"05@````````0`
M````````:@0``!(`#0!D*P```````(@"`````````@0``!(`#0!0*@``````
M``@!````````&`0``!(`#0`05@```````'P`````````-P0``!``%P"HP`$`
M````````````````;0,``!``%P"`L`$`````````````````B00``!(`#0!P
M,P```````)``````````Z`,``"``%@``L`$`````````````````5@0``!``
M%P"`L`$`````````````````[`,``!(`#0#4'P``````````````````Y@,`
M`!``%@``L`$`````````````````H@,``!``%@"`L`$`````````````````
MW@(``!(`#0!`'0```````)0"`````````%])5$U?9&5R96=I<W1E<E1-0VQO
M;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A
M8FQE`%!,7V1O7W5N9'5M<`!097)L7V=V7V9E=&-H<'8`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?;&]C:P!097)L7V=E=%]S=@!097)L7VYE=UA3`&)O;W1?
M1'EN84QO861E<@!P97)L7W)U;@!P97)L7W!A<G-E`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]S=E]S971P=FX`<&5R;%]C;VYS=')U8W0`<&5R;%]D97-T<G5C=`!P
M97)L7V%L;&]C`%!E<FQ?8W)O86M?;F]C;VYT97AT`'!E<FQ?9G)E90!097)L
M7W-A9F5S>7-M86QL;V,`4&5R;%]S>7-?:6YI=#,`4&5R;%]N97=84U]F;&%G
M<P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?=&5R;0!03%]T:')?:V5Y
M`%]?97)R;F]?;&]C871I;VX`<F5A9`!O<&5N-C0`;'-E96LV-`!P=&AR96%D
M7V=E='-P96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T
M86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H
M<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R
M;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS
M=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN
M:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C
M:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?
M96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L
M:6)P97)L+G-O`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0M;&EN=7@M
M86%R8V@V-"YS;RXQ`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C
M`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E;F%M90!P87)?
M9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A=&%?<W1A<G0`
M7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C
M<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A<E]I;FET7V5N=@!S
M:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E
M<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXQ-P`O=7-R+VQI8B]P97)L-2\U+C,T
M+V-O<F5?<&5R;"]#3U)%``````````(``@`"``(``@`"`````@`"``(``@`"
M``(````"```````"``(````"``````````(``@`"`````P````,``@`"``(`
M`@`#```````$``(``@`"`````@`"``(``@`````````"`````@````(`````
M`````@````,``@`"``(``P```````@````,``@`"``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!`#8#```0````(````)>1E@8```0`M@0````````!``$`'`,``!``
M```@````EY&6!@```P"V!`````````$``0`L`P``$`````````"7D98&```"
M`+8$````````,*L!```````#!````````/`@````````.*L!```````#!```
M`````*`@````````N*T!```````#!````````)!6````````F*X!```````#
M!````````#!3````````$*\!```````#!````````!!6````````2*\!````
M```#!````````*!6````````@*\!```````#!````````&!4````````D*\!
M```````#!````````$`=````````X*\!```````#!````````-!2````````
M"+`!```````#!`````````BP`0``````&+`!```````#!````````,A6````
M````(+`!```````#!````````-!6````````,+`!```````#!````````-A6
M````````.+`!```````#!````````.A6````````0+`!```````#!```````
M`/!6````````2+`!```````#!````````/A6````````4+`!```````#!```
M``````!7````````8+`!```````#!`````````A7````````:+`!```````#
M!````````!!7````````>+`!```````#!````````(A:````````L*T!````
M```!!````P``````````````P*T!```````!!```!```````````````R*T!
M```````!!```!0``````````````T*T!```````!!```!@``````````````
MV*T!```````!!```!P``````````````X*T!```````!!```"```````````
M````Z*T!```````!!```"0``````````````\*T!```````!!```"@``````
M````````^*T!```````!!```"P```````````````*X!```````!!```#```
M````````````"*X!```````!!```#0``````````````$*X!```````!!```
M#@``````````````&*X!```````!!```#P``````````````(*X!```````!
M!```$```````````````**X!```````!!```$@``````````````,*X!````
M```!!```$P``````````````.*X!```````!!```%```````````````0*X!
M```````!!```%0``````````````2*X!```````!!```%@``````````````
M4*X!```````!!```%P``````````````6*X!```````!!```&```````````
M````8*X!```````!!```&0``````````````:*X!```````!!```&@``````
M````````<*X!```````!!```&P``````````````>*X!```````!!```'0``
M````````````@*X!```````!!```'@``````````````B*X!```````!!```
M'P``````````````D*X!```````!!```(```````````````H*X!```````!
M!```(0``````````````J*X!```````!!```(@``````````````L*X!````
M```!!```(P``````````````N*X!```````!!```)```````````````P*X!
M```````!!```)0``````````````R*X!```````!!```)@``````````````
MT*X!```````!!```)P``````````````V*X!```````!!```*```````````
M````X*X!```````!!```*0``````````````Z*X!```````!!```+```````
M````````\*X!```````!!```+0``````````````^*X!```````!!```+@``
M`````````````*\!```````!!```+P``````````````"*\!```````!!```
M,```````````````&*\!```````!!```,0``````````````(*\!```````!
M!```,@``````````````**\!```````!!```,P``````````````,*\!````
M```!!```-```````````````.*\!```````!!```-0``````````````0*\!
M```````!!```-@``````````````4*\!```````!!```-P``````````````
M6*\!```````!!```.```````````````8*\!```````!!```.0``````````
M````:*\!```````!!```.@``````````````<*\!```````!!```.P``````
M````````>*\!```````!!```/```````````````B*\!```````!!```/0``
M````````````F*\!```````!!```/@``````````````H*\!```````!!```
M/P``````````````J*\!```````!!```0```````````````L*\!```````!
M!```0@``````````````N*\!```````!!```0P``````````````P*\!````
M```!!```1```````````````R*\!```````!!```10``````````````T*\!
M```````!!```1@``````````````V*\!```````!!```1P``````````````
MZ*\!```````!!```2```````````````\*\!```````!!```20``````````
M````^*\!```````!!```2@``````````````B*T!```````"!```$0``````
M````````D*T!```````"!```'```````````````F*T!```````"!```*```
M````````````H*T!```````"!```*P``````````````7R0#U?U[OZG]`P"1
MSP``E/U[P:C``U_6\'N_J=```+`1PD;Y$`(VD2`"']8?(`/5'R`#U1\@`]70
M``"P$<9&^1`B-I$@`A_6T```L!'*1OD00C:1(`(?UM```+`1SD;Y$&(VD2`"
M'];0``"P$=)&^1""-I$@`A_6_7NYJ?T#`)'S4P&IU```L(-R1_GU6P*I]QL`
M^>*'!*GB(P&19`!`^>0W`/D$`(#2PP``L.%#`9'@7P"YX',!D6-X1_E@`#_6
MP```L,(``+##``"P0J!'^0#,1_GA`P*J8Z1'^6``/];```"P`#!'^0``0#E@
M"P`TTP``T-4``+#6``"PM29'^=921_F@`D"YP`(_U@(H4CE"`!\R`B@2.:`"
M0+G``C_6`RA2.<$``+#B7T"Y8P``,@,H$CDA2$?Y0!``$54,`!$`?'V3(``_
MUN,#`*KF*T#YP```T&0B`I'E7T"Y`CQ`^2$``)#'`$#Y(>`ID2```)```"J1
M9P0`J8,$`/EB``&IOP0`<2T+`%0A`(#2'R`#U2`,`!'$>&'X(00`D638(/B_
M``%K;/__5*4,`!&E?'V3=B("D7]H)?C%``"PX@,5*@$``+`$`(#2I;A'^2'`
M)9'`#D#YH``_UO4#`"H@!@`T=B("D<$``+#WDP&1(2Q'^<`.0/D@`#_6(```
MD.$#%ZH``""1C0``E(`%`+1S(@*1P0``L"$81_E@#D#Y(``_UL```+``K$?Y
M```_UI1R1_GA-T#Y@`)`^2```,H@!@"UX`,5*O-30:GU6T*I]QM`^?U[QZC`
M`U_6P```L-,``-``0$?Y```_UF(B`I%`#`#Y``0`M,$``+#5``"PU@``L"$4
M1_D@`#_6H"9'^<%21_D``$"Y(``_UA_<*#F8__\7P0``L,`.0/DAY$?Y(``_
MUO4#`"K+__\7P`I`^6```+16"`"4TO__%^$#%ZH@``"0`$`>D5D``)3`"@#Y
M@/G_M$X(`)3*__\7!02`TK'__Q?!``"P(`"`4B'P1OD@`#_6P```L`!@1_D`
M`#_67R0#U1T`@-(>`(#2Y0,`JN$#0/GB(P"1Y@,`D<```+``R$?YPP``L&.(
M1_G$``"0A-Q&^4+__Y=)__^7P```D`!L1_E```"T0?__%\`#7]8?(`/5'R`#
MU1\@`]7```"P```"D<$``+`A``*1/P``Z\```%3!``"0(?1&^6$``+3P`P&J
M``(?UL`#7];```"P```"D<$``+`A``*1(0``RR+\?]-!#(&+(?Q!D\$``+3"
M``"00NQ'^6(``+3P`P*J``(?UL`#7]8?(`/5_7N^J?T#`)'S"P#YTP``L&`"
M0CE``0`UP0``D"$`1_F!``"TP```L``$0/D@`#_6V/__ER``@%)@`@(Y\PM`
M^?U[PJC``U_6'R`#U1\@`]7<__\7'R`#U1\@`]4?(`/5_7N[J?T#`)'S4P&I
M(`<`M/=C`ZGW`P"JP```D/DC`/D`V$?Y&0!`^9D&`+3U6P*I]@,!JA4`@%+@
M`D`Y'_0`<0080'H!`P!4,P-`^?,!`+38``"0M7Y`D_0#&:H8.T?YX@,5JN$#
M%ZK@`Q.J``,_UH```#5@:G4X'_0`<2`"`%23CD#X\_[_M?5;0JGW8T.I^2-`
M^>`#$ZKS4T&I_7O%J,`#7];U`Q>JH!Y`.!_T`'$$&$!ZH?__5+4"%TOC__\7
ME`(9R[4&`)%S`A6+E/Y#D]0"`+G@`Q.J\U-!J?5;0JGW8T.I^2-`^?U[Q:C`
M`U_6$P"`TNC__Q<3`(#2]V-#J?DC0/GD__\7'R`#U1\@`]7]>[*I_0,`D?=C
M`ZG7``"0X7)'^2(`0/GB;P#Y`@"`TL```+3S4P&I\P,`J@$`0#E!`0`U\U-!
MJ>!R1_GA;T#Y``!`^2```,J@"P"U]V-#J?U[SJC``U_6P0``D"$(1_D@`#_6
M]`,`JF#^_[38``"0]5L"J=8``)#Y:P2IV0``D-:R1_D8ZT;Y.2-'^>`#%*K`
M`C_6H`8`M`%,0#D53`"1/[@`<6$``%2A!D`Y`?__-`!,0#D?N`!Q``<`5.`#
M$ZH``S_6^@,`JN`#%:H``S_60`,`"P`(`!$`?$"3(`,_UL8``)#E`Q6J`@"`
MDO4#`*K&[$;Y(0"`4N0#$ZH#``#P8X`<D<``/];#``"0X0,5JN)C`9$``(!2
M8_A&^6``/]8?!``QH```5.!K0+D`#!02'Q!`<>`#`%3!``"0X`,5JB'X1_D@
M`#_6P0``D.`#%:HAJ$?Y(``_UN`#%*K``C_6P/G_M1\@`]7!``"0X`,4JB%<
M1_D@`#_6P0``D.`#$ZHAC$?Y(``_UO-30:GU6T*I^6M$J:G__Q>@!D`Y'[@`
M<>'X_U2@"D`Y(/?_-,3__Q?@`Q6JD___E^3__Q?```"0\U,!J0!@1_GU6P*I
M^6L$J0``/];]>[6IX0,`JOT#`)'S4P&ITP``D/0#`*IC<D?YXJ,`D0``@%)D
M`$#YY%<`^00`@-+#``"08YQ'^6``/];@`0`UX3M`N0(`E%(A#!02/Q!`<200
M0GI@`0!4<W)'^>)70/EA`D#Y00`!RL$!`+7S4T&I_7O+J,`#7]8``(!2]___
M%\(``)#@`Q2J00"`4D)T1_E``#_6'P``<>`7GQKO__\7P```D`!@1_D``#_6
M_7N^J<$``)#]`P"1(>A&^?,+`/GS`P"J(``_U@($`-%B`@*+?P("ZZ,``%0T
M```40@0`T7\"`NL``@!40`!`.1^\`'%@__]4?P("ZX(%`%1"!`#1?P("ZP`!
M`%0?(`/50`!`.1^\`'$@`@!40@0`T7\"`NMA__]48`)`.1^\`'%`!`!4P0``
MD````/#S"T#Y`*`<D?U[PJ@P6$?Y``(?UD``0#D?O`!Q@0``5$($`-%_`@+K
M8___5$(`$\L``(#200@`D3\$0/%(`0!4P```L`2@`I'@`P2JQ```D$($`)'A
M`Q.JA"A'^0,`@M*``#_6\PM`^?U[PJC``U_6?P("ZV']_U3=__\7P0``D```
M`/#S"T#Y`$`;D?U[PJ@P6$?Y``(?U@P*@M+_8RS+PP``D/U[`*G]`P"18_Q&
M^?-3`:G3``"0]5L"J?8C`9'U`P"J8G)'^?=C`ZGW`P&J0`!`^>`G"/D``(#2
MX0,6J@```/#B_X'2`,`<D6``/]8?``!Q30<`5`,$`%'!``"0(21'^<+*8S@X
M`$"Y`@0`-2,%`#1T?$"3PP``D.(#%*K@`Q:J8]1'^>$%@%)@`#_6(`0`M,$`
M`)#@`Q@J(5!'^2``/];$``"0XP,4JN(#%JKA`Q6JA.!'^8``/]9S<D?YX2=(
M^6`"0/D@``#*``0`M0P*@M+]>T"I\U-!J?5;0JGW8T.I_V,LB\`#7];C`P`J
MX06`4N`#%JIT?$"3PP``D.(#%*ICU$?Y8``_UD#\_[4?(`/5P0``D.`#&"HA
M4$?Y(``_UL,``)#B`Q>JX0,5JF,T1_E@`#_6X?__%\```)``)$?Y&`!`N?/_
M_Q?```"0`&!'^0``/];]>[FI_0,`D?-3`:G4``"0\P,`JO5;`JGU`P&J]V,#
MJ=@``)#Y:P2I(@!`.8%R1_E?]`!Q&.M&^2(`0/GB-P#Y`@"`TK46E9K@`Q6J
M``,_UO<#`*KADP&1X`,3JF3^_Y=`"`"T]@,`J@`#/];_`@#K"0<`5/AG@+G9
M``"0&/-]TV`"0#D?]`!Q!!A`>@`-`%3C`Q.J8AQ`.%_T`'%$&$!ZH?__5&,`
M$\MC?$"3.=M'^<$``)#@"@"1(2!'^0```XLW`T#Y(``_UN!J./C``@"TXV>`
MN>`#$ZHB`T#Y`11`.$-X8_@_]`!Q)!A`>F$``#G```!4`A1`.&(<`#A?]`!Q
M1!A`>H'__U2A!X!2``"`TF$4`#BB:F`X8F@@.``$`)&B__\UE')'^>$W0/F`
M`D#Y(```RF`(`+7S4T&I]5M"J?=C0ZGY:T2I_7O'J,`#7]8!`(#2HFIA.,)J
M(3@A!`"1HO__-?#__Q?9``"0^RL`^2#;1_D;`$#Y8`-`^<`%`+3@`QNJ%@"`
M4A\@`]4!C$#XX@,6*M8&`!&A__^U0`P`$0!\?9/!``"P(HA`N:("`#4B`(!2
M(H@`N<$``)`A($?Y(``_UOH#`*I`!`"TPP``D-A^?9/A`QNJX@,8JF/@1OE@
M`#_6(-M'^1H``/G`!@`17]L@^/9G`+G[*T#YH?__%\(``)#A`P"JX`,;JD)4
M1_E``#_6^@,`JB';1_D@``#Y@`$`M-A^?9/Q__\7`P"`TI___Q<``H#2%@"`
M4MK__Q?```"0^RL`^0!@1_D``#_6^RM`^;3__Q<?(`/5_7N^J?T#`)'S4P&I
MU```D-,``)"4)D?Y<U)'^8`"0+E@`C_6@`)`N6`"/];"``"0Q```D",``/`!
M``#P0A!'^6.`&Y&$F$?Y(0`=D8``/]:``D"Y8`(_UL8``)`$``#P\U-!J83`
M*9']>\*HXP,$JM"\1_D"``"P`0``\$+`-Y$A@!V1!0"`4@`"']8?(`/5_7N_
MJ<```)#!``"0_0,`D0`D1_DA4$?Y``!`N2``/];$``"0P@``D/U[P:@C``#P
M0A!'^6.`&Y&0F$?Y`0``\"$`'9$``A_6'R`#U1\@`]4,"H32_V,LRP`(@M+]
M>P"I_0,`D?-3`:G4``"0\^,`D?5;`JGV8R"+%0"`TH!R1_D!`$#YX2<0^0$`
M@-+```"0`!Q'^0``/];D`P`JQ@``D"(`@M(A`(!2X`,3JL;L1OD%``#P`P``
M\*7@'9%C`!Z1P``_UL,``)#@`Q.JX0,6J@(`@M)C_$;Y8``_U@`"^#?!``"0
M\P,`J@`$`!$A($?Y`'Q`DR``/];U`P"J``$`M,,``)!S?D"3X0,6JN(#$ZIC
MV$;Y8``_UK]J,SB4<D?YX2=0^8`"0/D@``#*``$`M>`#%:H,"H32_7M`J?-3
M0:GU6T*I_V,LB\`#7];```"0`&!'^0``/]8?(`/5'R`#U;S__Q<,'H+2_V,L
MR_U[`*G]`P"1^6L$J=H``)!"<T?Y\U,!J?,#`:KU6P*IX9,!D?4#`*I#`$#Y
MXW<(^0,`@-(```#P`$`>D5;]_Y?T`P"JP@``D.`#%:KA!8!20L1'^4``/]9`
M`@"TX0,5J@```/``@!Z1T/[_E^`#%:I:<T?YXG=(^4$#0/E!``'*80\`M0P>
M@M+]>T"I\U-!J?5;0JGY:T2I_V,LB\`#7];!``"0]V,#J>`#%:HAZ$;Y%P``
M\"``/];X`P"JP0``D.`#$ZHA6$?Y(``_UL(``)#APAZ10N1&^4``/];S`P"J
M(`P`M!D``/#VHP.1.:,<D?LK`/D;``#P>T,;D6`"0#G`!P`T]```M,(``)#A
M`Q.JX`,4JD*`1_E``#_6H`4`-,$``)#@`Q.J(>A&^2``/]8"!`!1XP,`JF#"
M(HMARF(X/[P`<2$!`%0?(`/5XP,"*D($`%$?```Y8,(BBV'*8C@_O`!Q0/__
M5``'`!$#``,+?_P_<<P#`%3'``"0`@""TB$`@%+D`Q.JY^Q&^>8#%:KE`QFJ
MX`,6J@,``/!CX!Z1X``_UL,``)#BHP&1X0,6J@``@%)C^$;Y8``_UJ```#7@
M>T"Y``P4$A\@0'&@`@!4P@``D.'"'I$``(#20N1&^4``/];S`P"JH/C_M?=C
M0ZG[*T#YFO__%Y0``+2``D`Y'[@`<8```%3S`QNJ(P"`4M;__Q>`!D`YP/W_
M-/O__Q?"``"0X`,6JB$`@%)"=$?Y0``_UN#\_S7A`Q:J````\`"`'I%9_O^7
MP0``D.`#%JHA6$?Y(``_UO=C0ZG[*T#YA/__%_=C0ZE]__\7P```D/=C`ZD`
M8$?Y^RL`^0``/]8?(`/5`@!`.>$#`*KB```T'R`#U2$$`)%?O`!Q`!"!FB(`
M0#F"__\UP`-?UA\@`]4?(`/5@```M`$`0#E!```TF?W_%\$``)````#P`$`;
MD3!81_D``A_6_7NWJ2$``/`A@!N1_0,`D?-3`:G4``"0\W,!D8-R1_GU6P*I
MU@``D/=C`ZD5``#PM0(?D?EK!*G6VD?Y9@!`^>9'`/D&`(#2)AQ!J>8?!JDD
M%$*IY!<'J2%@0'GA`P%YX0,3JN`#%:J5_/^7``(`M,("0/GC7X"Y0`P#BP$$
M0/E!>"/XX?[_M!\@`]4!"$#Y`00`^0`@`)&A__^UX0,3JN`#%:J&_/^70/[_
MM=8``)`5``#PM4(?D=;:1_GA`Q.JX`,5JG[\_Y?@`0"TP@)`^>-?@+E`#`.+
M`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q6J</S_EV#^_[76
M``"0%0``\+5B'Y'6VD?YX0,3JN`#%:IH_/^7X`$`M,("0/GC7X"Y0`P#BP$$
M0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,5JEK\_Y=@_O^UU@``
MD!4``/"UHA^1UMI'^>$#$ZK@`Q6J4OS_E^`!`+3"`D#YXU^`N4`,`XL!!$#Y
M07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%:I$_/^78/[_M=8``)`5
M``#PM\(?D=;:1_GA`Q.JX`,7JCS\_Y?@`0"TP@)`^>-?@+E`#`.+`01`^4%X
M(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q>J+OS_EV#^_[6W``#P%@``
MT-8"()'WVD?YX0,3JN`#%JHF_/^7X`$`M.("0/GC7X"Y0`P#BP$$0/E!>"/X
MX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,6JAC\_Y=@_O^UMP``\!8``-#8
M0AZ1]]I'^>$#$ZK@`QBJ$/S_E^`!`+3B`D#YXU^`N4`,`XL!!$#Y07@C^.'^
M_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#&*H"_/^78/[_M;@``/`7``#0^4(@
MD1C;1_GA`Q.JX`,9JOK[_Y?@`0"T`@-`^>-?@+E`#`.+`01`^4%X(_CA_O^T
M`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QFJ[/O_EV#^_[6Y``#P&```T!J#()$Y
MVT?YX0,3JN`#&JKD^_^7X`$`M"(#0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(
M0/D!!`#Y`"``D:'__[7A`Q.JX`,:JM;[_Y=@_O^UN@``\!D``-`YPR"16MM'
M^>$#$ZK@`QFJSOO_E^`!`+1"`T#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y
M`00`^0`@`)&A__^UX0,3JN`#&:K`^_^78/[_M;H``/`9``#0.8,>D5K;1_GA
M`Q.JX`,9JKC[_Y?@`0"T0@-`^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$
M`/D`(`"1H?__M>$#$ZK@`QFJJOO_EV#^_[7A`Q.J````T```(9&E^_^7X0,`
MJF```+0`@R"1)OW_E^$#$ZH```#0`&`AD9W[_Y?A`P"J@```M````-``8!N1
M'?W_E^$#$ZH```#0`,`AD93[_Y?A`P"J0`(`M,!"'I$5_?^7H,(?D0$``-`A
MH"*1$?W_EY1R1_GA1T#Y@`)`^2```,K@`P"U\U-!J?5;0JGW8T.I^6M$J?U[
MR:C``U_6X0,3J@```-```"*1??O_E^$#`*J```"TX$(@D?[\_Y?I__\7`2J(
MTN(31_A!ZJOR88C)\J$HZ/)?``'K0?S_5.&31WC`J8=2/P``:\'[_U3@0B"1
MX>\!D>_\_Y?:__\7H```\`!@1_D``#_6'R`#U?U[O:G]`P"1\U,!J;,``/#4
M``"087)'^8`20+DB`$#YXA<`^0(`@-(?!``Q(`$`5'-R1_GB%T#Y80)`^4$`
M`<HA`@"U\U-!J?U[PZC``U_6X9,`D0```-``0""13?O_E^$#`*H``(!2H0``
MM"``0#D?P`!Q!!A`>N`'GQJ`$@"Y[/__%Z```/``8$?Y```_UOU[OZF@``#P
M_0,`D0`$1_D``#_6H0``\"&$1_D@`#_60```M```0/G]>\&HP`-?UOU[NZG]
M`P"1]5L"J;4``/`6``#0]V,#J=C"(I'A$P&1MW)'^?-3`:GT`P"JX@)`^>(G
M`/D"`(#2X`,8JB7[_Y>```"T`0!`.?,#`*JA`0`UM7)'^>$G0/F@`D#Y(```
MRJ`&`+7A`Q2JP,(BD?-30:GU6T*I]V-#J?U[Q:B:_/\7H@``\.$#%*I"Z$?Y
M0``_UD`!`+3A)T#YX`)`^2```,J@!`"U\U-!J?5;0JGW8T.I_7O%J,`#7]:V
M``#PX`,4JM;J1OG``C_6]0,`JN`#$ZK``C_6H0``\*`"`(L`"`"1(2!'^2``
M/]:G``#PY@,3JB$`@%+D`Q2JY^Q&^?,#`*H%``#0`P``T*7`'I%CX!Z1`@"`
MDN``/];A)T#YX`)`^2```,J```"UX0,3JN`#&*K/__\7H```\`!@1_D``#_6
M##B0TO]C+,L#`I#2_7L!J?U#`)'[<P:IW```D()#`)'U6P.IM@``\/L#`*I&
MG$"IYA\)J>!C(XM*+$*I\U,"J4@D0ZGW8P2I&```T$041*GY:P6I^3,"D48<
M1:GFGPJIU')'^>HO#*E,#$#Y@0)`^0'4`/D!`(#20C!`^>$#&:H`0QZ1[%,`
M^>)?`/GH)PVIY!<.J;_Z_Y>```"T`0!`.?,#`*H!*``UH```\``$1_D``#_6
MH0``\"&$1_D@`#_6`"(`M!<`0/G7(0"TH0``\.`#%ZHAZ$;Y(``_U@#X?].A
M``#PX3L`^:$``/``!`"1(2!'^2``/];Z`P"JY`)`.80G`#2@``#P`P``T/4#
M&JIT(".1$^Q&^>`_`/D?(`/5X`,5JN,#%*H"`("2(0"`4F`"/]:U"@"1Y!Y`
M."3__S4```#0]",#D0!@&Y$#```4@(9`^*`+`+3A`QFJC?K_E_,#`*I@__^T
M`0!`.2'__S1!^_^7X/[_-*$``/#@`Q.J(5A'^2``/];W`P"JX`D`M.`[0/D5
M``#0%.A&^>`#%ZJ``C_6\P,`JN`#&JJ``C_6H0``\',"``MS$A`1(2!'^7-^
M0)/@`Q.J(``_UO0#`*JH``#P`@"`DB$`@%+G`QJJ".U&^>0#%ZJEHAR1!@``
MT`,``-#&0".18V`CD0`!/]:B``#PX`,4J@$X@%)"_$?Y0``_UA\$`#'A``!4
MH```\`#T1_D``#_6!0!`N;]$`'$!&@!4HP``\.+#`Y'A`Q2J``"`4F.<1_E@
M`#_6^@,`*D`&`#2@``#PI0``\&,#0/D"``#0``Q'^>0#%*JE?$?Y0J`DD0``
M0/DA`(!2$P"`TJ``/];6<D?Y``*0TN!C((L!U$#YP`)`^2```,K`+@"UX`,3
MJ@PXD-+]>T&I\U-"J?5;0ZGW8T2I^6M%J?MS1JG_8RR+P`-?UK0``/#S0P*1
M%0"`4I1:1_EWVG7XMP$`M.`"0#E@`0`TM08`$>`#%ZKA^O^7(/__-.`#%ZJ`
M`C_6]P,`JF#T_[5WVG7XM_[_M1<`@-*?__\7X`-!N0`,%!(?$$!Q@?G_5*``
M`/#W"T&Y``1'^0``/];_`@!KP?C_5.`#0;D`(``2'P`'<4'X_U2A``#PX`,3
MJB$@1_D@`#_6\P,`J@$``-`@`":1X0,9J@CZ_Y?A`P"J(!0`M&`#0/F=_/^7
M]P,`JJ`3`+2A``#PX`,7JB'H1OD@`#_6X@,`JA\,`'%M`@!4XCL`^:(``/``
M?$"3`0``T$*`1_D`$`#1(2`FD>`"`(M``#_6(`$`->([0/E?$`!Q8!X`5$(4
M`%'@RF(X'[P`<>`=`%0?(`/5@!-`N1\$`#%@$`!4&P``T&`1`#1@0R"1`0``
MT"&@(I%E^_^7H```\+<``/`;``#0&0``T``<1_DYXR:1```_UN8#`"JH``#P
M9\,ID:6B')'D`Q2J".U&^>`#$ZH#``#0`@"`DF.@)I$A`(!2``$_UO?V1_D6
M```4X`(_U@``0+D?1`!Q(0,`5*```/!:!P`1`!Q'^0``/];F`P`JJ```\&'#
M*9'A`P#YYP,:*@CM1OFEHAR1Y`,4JN,#&:K@`Q.J`@"`DB$`@%(``3_6H@``
M\.`#$ZH!.(!20OQ'^4``/]8?!``QH/S_5*$``/#@`Q2J(:A'^2``/];A`Q.J
M`$,>D2W[_Y?@`Q.J<O[_EV+__Q>T``#P\Z,"D14`@%*46D?Y8-IU^(`!`+3A
M`QFJM08`$9SY_Y=@__^T`0!`.2'__S2``C_6]P,`JJ#<_[5@VG7XP/[_M:$`
M`/"@`8#2(2!'^2``/];Z`P"J!@``T*```/#7`".19`J`4N`[`/GF_O\7H```
M\*8``/!C`T#YY`,4J@`,1_D"``#0QGQ'^4*@(Y$``$#Y(0"`4A,`@-+``#_6
M.?__%T?^_Y<!`I#2X&,ABP'40/F``D#Y(```RL`5`+7@`Q.JH0``\/U[0:D,
M.)#2\U-"J?5;0ZGW8T2I^6M%J?MS1JDP6$?Y_V,LBP`"']:@``#PX#\`^=+^
M_Q=W`T#Y8___%QL``-#A`QFJ8$,@D6#Y_Y>@``"T``!`.1_``'$$&$!ZH0L`
M5)\3`+FB``#PX`,7J@$`@%(;``#00MQ'^4``/];Y`P`JX.W_-*,``/"[``#P
M0@"`4B$"@))W1$?Y^N,&D>`"/]9\TT?YX0,:JN`#&2K"`(#2@`,_UN#C1CF`
M```UX.=&.1\,`7$`"P!4HP``\`$`@-("`(!2X`,9*F-$1_E@`#_6H```\`#P
M1_D``#_6_`,`JJ$``/![TT?Y-TQ'^04``!3B`P`JX0,:JN`#'*K@`C_6X0,:
MJN`#&2H"`)#28`,_UA\``''L_O]4H0``\.`#&2KYPP61^R,&D2%D1_GZ`QFJ
M(``_UOL[`/FB``#PX`,9JN$#'*K\`QNJ0L!'^?O#!I%``#_6X#]`^0,``-!Y
M(".1%^Q&^1\@`]7@`QRJ1!=`.)P+`)'C`QFJ`@"`DB$`@%+@`C_6?P,<ZP'_
M_U3F.T#Y_\,&.:6B')'D`Q2JX`,3J@<``-`#``#0Y\`ID6-@)I$"`("2(0"`
M4N`"/]91__\7(`"`4H`3`+D9__\7>P=`^5OB_[2A``#PX`,;JB'H1OD@`#_6
M'PP`\8GA_U2B``#P`!``T6`#`(L!``#00H!'^2%`)I%``#_6'P``<?<2FYH"
M__\7X.M&.1\$`7'A]/]4X.]&.1\,`7&!]/]4X/-&.1\@`7$A]/]4X/=&.1\4
M`7'!\_]4X`,9*D(`@%(A!X"2X`(_UN$#&JK@`QDJ(@6`TH`#/]:H``#PY@,:
MJJ6B')'D`Q2J".U&^>`#$ZH'``#0`P``T.?`*9%C8":1`@"`DB$`@%(``3_6
M&O__%Z```/``8$?Y```_UOU[N:G]`P"1\U,!J;0``/"S``#P]5L"J;8``/#Y
M:P2IF29'^?=C`ZGWDP&1P7)'^7A21_DB`$#YXC<`^0(`@-(@`T"Y``,_UO4#
M`*H@`T"Y``,_UN(#`*JCPD(Y````T.$#%ZH`P!^10\0".:GX_Y>```"T`0!`
M.3_$`''`#0!4]?O_EYDF1_EX4D?Y(`-`N0`#/]:D``#P`0``T&,`@%(A0">1
MA&A'^2(`@%*``#_6]0,`JL`!`+0@`T"Y``,_UJ$*0/FC``#P`@``T$)@)Y%C
M-$?Y(0!`^6``/]:@"D#Y``!`^0`,0+E`#;`WFB9'^=4``)!Y4D?Y0`-`N2`#
M/]:D``#P`0``T&,`@%(A@">1A&A'^2(`@%*``#_6^`,`JB`"`+3A`Q>J````
MT`"`'I'[*P#Y=_C_E_L#`*I``T"Y>PD`M"`#/]8!"T#YHP``\.(#&ZIC-$?Y
M(0!`^6``/];[*T#YN2("D90F1_ES4D?Y@`)`N6`"/];X`P"J@`)`N6`"/]:C
M``#P(@"`4@$``-`AH">18Y!'^6``/];A`P"JHP``\.`#&*H"``#00@`HD6,T
M1_E@`#_6@`)`N6`"/];B`P"JX0,7J@```-``0!Z17\0".4_X_Y<@"P#Y\P,`
MJ@`#`+2B``#P`3B`4N`#$ZI"_$?Y0``_U@$$`!$_!`!Q!(A1>N$%`%36<D?Y
MX3=`^<`"0/D@``#*P`0`M?-30:GU6T*I]V-#J?EK1*G]>\>HP`-?U@`$0#E@
M\O\TD?__%R`'0/E/_?^7(`L`^?,#`*J@_/^UH0``T/LK`/D```"P`"`HD2&4
M1_D@`#_6(`,_UJ`B`I$""T#Y`01`^4``0/DA`$#Y4/G_E_LK0/FV__\7(`-`
MN0`#/]:A"D#YH@``T$*T1_DA`$#Y0``_UI#__Q>@``#0^RL`^0!@1_D``#_6
MM2("D?LK`/FD``#0XP,`*N(#$ZH```"PH09`^0#`*)&$E$?Y(0!`^8``/]8?
M(`/5_7N[J?T#`)'U6P*IM0``T*%R1_GS4P&I]`,`JO<;`/DB`$#YXB<`^0(`
M@-*@!@"T`0!`.6$&`#3>^/^7`0!`.?,#`*K!```T``0`D3^\`'%S$H":`0!`
M.8'__S6W``#PGP(`\?8'GQK@$D"Y'P0`,4`%`%0?``!QX`>?&M8"``IV`0`U
MM7)'^>$G0/F@`D#Y(```R@`&`+7S4T&I]5M"J?<;0/G]>\6HP`-?UH`"0#F@
M_O\THP``T`$``+#@`Q.J(4`CD6,X1_F"`(#28``_UJ#]_S6U<D?YX2=`^:`"
M0/D@``#*@`,`M>`#%*KS4T&I]5M"J?<;0/G]>\6H#?C_%Z$``-````"P`$`;
MD2%81_D@`#_6RO__%P```+#A$P&1`$`@D;_W_Y>@``"T``!`.1_``'$$&$!Z
M80``5/\2`+G1__\7(`"`4N`2`+G6^?\TU___%Z```-``8$?Y```_UO^#"M&H
M``#0XF,`D07@`)$)X`&1Y`,"JOU[`*G]`P"1`7%'^2,`0/GC3P'Y`P"`TJ$`
M0+F$0`"1HX1`^"$(P%J!`!_X8?Q@TV?\:-/G''B2)MQXTR$<"%/&''"2X^!#
MJB$`!JHA``.J@8`?^#\!!>L!_O]410`(D4$`0/E"(`"10P1`^40<0/EC``'*
M03!`^2$`!,HA``/*(_Q?TV$$`:HA?$"203P`^5\`!>MA_O]4`QA`J2HSC]($
M%$&I2E"K\NNS0:DI=)W28OQ;TVW\0M-"%`.JK7D#JJ$`!,HIVZWR(0`&BB$`
M!<IK`0J+(D`BB\'\0M,A>`:J0@`+BP<00/DN?$"2RP$$RHP!"HM"``<+:P$#
MBFL!!,HA``W*3_Q;TVL!!8OO%0*J:P$,BVL!#PM/_$+3(0`"BN)Y`JKLOT*I
M(0`.RG#]6],A``2+$!8+JE%\0)*,`0J+[P$*BR$`#(NL`0+*(0`0"[!]0))M
M_4+3C`$+BJUY"ZJ,`1#*2P`-RHP!#HMK`0&*C`$/BVL!$<HN_%O3:P$0B\X5
M`:KOPT.IC`$."R+\0M.._5O307@!JLX5#*JB`0'*0@`,BJU]0)+O`0J+0@`-
MRFL!#XL0`@J+;@$."XO]0M-L>0RJ0@`1BRL`#,K/_5O3(7Q`DFL!#HI"`!"+
M[Q4.JFL!`<I/``\+:P$-B]']0M/BMT2I+GH.JO#]6],0%@^J0@`*BVL!`HN"
M`0[*:P$0"XQ]0))"``^*\/U"TT(`#,H/>@^J0@`!BZ$!"HMM_5O30@`!BZT5
M"ZK!`0_*</U"TTT`#0LA``N*"WH+JN+#1:G.?4"2(0`.RK']0M,A``R+K/U;
MTXP5#:I"``J+(0`"B^(!"\I"``V*[WU`DD(`#\HL``P++7H-J@$""HM"``Z+
MD/U;TT(``8MA`0W*(0`,BFM]0)(0%@RJ(0`+RE``$`LA``^+XK]&J9']0M,L
M>@RJ#OY;T\X5$*H1_D+30@`*BR$``HNB`0S*0@`0BJU]0))"``W*+@`."S!Z
M$*KA`0J+0@`+B\_]6]-"``&+@0$0RB$`#HJ,?4"2[Q4.JB$`#,I/``\+(0`-
MB^*W1ZG1_4+3+GH.JNO]6]-K%0^J\?U"TT(`"HLA``*+`@(.RD(`#XH0?D"2
M0@`0RBL`"PLO>@^JH0$*BT(`#(MM_5O30@`!B\$!#\HA``N*SGU`DJT5"ZHA
M``[*30`-"R$`$(OBPTBI<?U"TRMZ"ZJL_5O3C!4-JK']0M-"``J+(0`"B^(!
M"\I"``V*[WU`DBP`#`M"``_*`0(*BRUZ#:I"``Z+COU;TT(``8MA`0W*\$]`
M^7%]0)+.%0RJ(0`,BD(`#@N+_4+3(0`1RFQY#*H0`@J+(0`/BZL!#,I._%O3
M(0`0B\X5`JKP4T#YK7U`DFL!`HHA``X+:P$-RD[\0M/.>0*J$`(*BVL!$8N"
M`0[*:P$0BXQ]0)+P5T#Y+_Q;TT(``8KO%0&J0@`,RFL!#PL0`@J+0@`-BR_\
M0M-"`!"+[WD!JFW]6]/P6T#YP0$/RB$`"XK.?4"2K14+J@H""HLA``[*</U"
MT[(!`@L0>@NJ(0`,BT)`+8OK7T#Y(0`*B^H!$,I,_EO32@$"2FT!"8N,%1*J
M0OY"TTH!#HN1`0$+2@$-BTUX$JKB8T#Y+$`LBP$"#<HK_EO3+``,2FL5$:I!
M``F+@D$OBR_^0M-N`0H+[WD1JD(``8OA9T#Y2D$KBZL!#\K,_5O3:P$*2HP5
M#JHJ``F+84$PB]#]0M.2`0(+#GH.JD)`+(OL`0[*2_Y;TXP!`DIK%1*JC4$M
MBTS^0M.2>1*J(0`*B^HS3:EQ`0$+(4`KB\L!$LIK`0%*0@$)BRK^6]-*%1&J
MH@$"BX$!"8LM_D+3;$$OBU`!`@NQ>1&J@0$!B^QS0/E"0"J+2@(1R@O^6]-"
M`0)*:Q40JHP!"8M"0"Z+#?Y"TV\!`0NP>1"J0@`,B^QW0/DA0"N+*P(0RNK]
M6]-A`0%*2A4/JHP!"8LA0#*+3@$""R$`#(OM_4+30D`JB^Q[0/FO>0^J"@(/
MRLO]6]-K%0ZJ2@$"2H(!"8O,_4+3?@$!"XYY#JKL?T#Y(4`KB^L!#LI-03&+
M:P$!2LK_6]-*%1ZJH@$"BX$!"8O-_T+3;$$PBU(!`@NM>1ZJ@0$!B^R#0/E"
M0"J+R@$-RDO^6]-"`0)*:Q42JHP!"8M"0"^+3_Y"TT(`#(OL>1*J<0$!"R%`
M*XNK`0S*80$!2BK^6],A0"Z++OY"TTH5$:K1>1&J[[M0J5`!`@M"0"J+B@$1
MR@O^6]-*`0)*:Q40JDU!+8OO`0F+P@$)BR$`#XL._D+3;P$!"]!Y$*JB`0*+
M(4`KB^K]6],K`A#*2A4/JFL!`4KMCT#Y3@$""VQ!+(M"0"J+H0$)B\O]6]/M
M_4+3:Q4.JJ]Y#ZJ!`0&+[)-`^6T!`0L*`@_*(4`KBT(!`DJ,`0F+0D`QBZK]
M6]/1_4+32A4-JBYZ#JI"``R+[)=`^5$!`@OK`0[*0D`JBV$!`4J+`0F+(4`P
MBRS^6].P_4+3C!41J@UZ#:HA``N+ZYM`^9`!`0O*`0W*(4`LBTH!`DIB`0F+
M2D$OBPO^6],O_D+3:Q40JDH!`HOB>1&J\9]`^6\!"@NL`0+*2D$KBXP!`4HA
M`@F+C$$NBQ'^0M/N_5O3C`$!B\X5#ZHA>A"J\*-`^=$!#`M+``'*C$$NBVL!
M"DH*`@F+:T$MB_#]0M,M_EO3#WH/JJT5$:IK`0J+\*=`^:H!"PLN``_*:T$M
MB\X!#$H,`@F+PD$BBU#]6],N_D+30@`,B]%Y$:H0%@JJ[*M`^5``$`OB`1'*
M2P`+2HD!"8M"_4+384$ABP[^6]-+>`JJ(0`)B\X5$*HN``X+*@(+JN&O0/EI
M`1$*2@$0B@+^0M-*`0FJC)N7TFSCL?)0>!"J(0`,BTI!+XO/_5O3:0$0JDH!
M`8OO%0ZJX;-`^4\!#PL"`@L**0$.BBD!`JK*_4+33GD.JB$`#(LI03&+[?U;
MTP("#JHI`0&+K14/JD(`#XKAMT#Y+0$-"\D!$`I"``FJ(0`,B^G]0M-"0"N+
MJ_U;TR]Y#ZI"``&+:Q4-JDL`"PO!`0^JXKM`^>H!#@HA``V*J?U"TR$`"JHM
M>0VJ0@`,BR%`,(MP_5O3Z@$-JB$``HL0%@NJXK]`^3``$`M*`0N*H0$/"FG]
M0M-*`0&J*WD+JD$`#(M*02Z+#OY;TZD!"ZI*`0&+SA40JF(!#0KAPT#Y3@$.
M"RD!$(H*_D+3*0$"JE!Y$*HA``R+*4$OB\_]6]-B`1"J*0$!B^\5#JKAQT#Y
M+P$/"T(`#HH)`@L*0@`)JB$`#(O)_4+30D`MB^W]6],N>0ZJ0@`!BZT5#ZI-
M``T+`0(.JN++0/G*`1`*(0`/BNG]0M,A``JJ+WD/JD(`#(LA0"N+J_U;T\H!
M#ZHA``*+:Q4-JN+/0/DK``L+2@$-BN$!#@JI_4+32@$!JBUY#:I!``R+2D$P
MBW#]6]/I`0VJ$!8+JDH!`8LI`0N*X=-`^4H!$`NP`0\*8OU"TRD!$*I+>`NJ
M(0`,BRE!+HM._5O3H@$+JBD!`8O.%0JJX==`^2X!#@M"``J*:0$-"D(`":HA
M``R+2?U"TT)`+XO/_5O3,'D*JD(``8OO%0ZJ3P`/"V$!$*KBVT#Y"0(+"B$`
M#HK*_4+3(0`)JDYY#JI"``R+(4`MB^G]6],*`@ZJ*14/JB$``HOBWT#Y(0`)
M"TH!#XK)`1`*2@$)JNG]0M,O>0^J0@`,BTM!*XLM_%O3K14!JLD!#ZIK`0*+
M*0$!BN+C0/EK`0T+[0$."BK\0M,I`0VJ07D!JD(`#(LI03"+;?U;TRD!`HNM
M%0NJX@$!JNKG0/DI`0T+0@`+BBT`#PI"``VJ2@$,BVW]0M-"0"Z++OU;TZUY
M"ZI"``J+SA4)JDX`#@LJ``VJ(OU"TTH!"8I">`FJL`$!"NLG7:E*`1"J2D$O
MB\_]6]/O%0ZJT/U"TVL!#(LI`0R+2@$+BZL!`JI/`0\+:P$.BDH`#0H.>@ZJ
M:P$*JNK]6]-A02&+2A4/JB$`"8M)``ZJ(0`*"]`!`@KJ\T#Y*0$/BBD!$*KK
M_4+32@$,BRE!+8MO>0^J*0$*BRW\6]/+`0^JZO=`^:T5`:HP_$+3+0$-"VL!
M`8KI`0X*`7H!JFL!":I)`0R+Z@$!JC$`#PI*`0V*2@$1JF)!(HM*02Z+J_U;
MTZ[]0M-"``F+:Q4-JLUY#:KI.U^I<`$""TM`*XLB``W*0@`+2LLZF-)+3+GR
M0D`OBP_^0M,L`0R+"?Y;TTH!#(LI%1"J,@$*"\X!"XOP>1"J0@`.BTS^6]-)
M02F+C!42JJH!$,KN`T'YD0$""TD!"4I"0"R+R@$+BR%!(8M._D+3*?Y;T])Y
M$JHI%1&J(0`*BPP"$LKJ!T'Y+P$!"XP!`DHA0"F+2@$+BXQ!+8OB_5O3+?Y"
MT[%Y$:J,`0J+0A0/JDD"$<KJ"T'Y3@`,"R$!`4KM_4+320$+BRI`,(O!_5O3
MKWD/JDH!"8LA%`ZJZ0]!^3``"@N"02*++`(/RH(!`DK-_4+3+`$+BTE`,HL"
M_EO3KGD.JBD!#(M"%!"J[!-!^5(`"0OM`0[*04$ABZ$!`4J*`0N++4`QBPS^
M0M-!_EO3D'D0JJH!"HLA%!*J[!=!^3$`"@LB02*+R0$0RB(!`DI-_D+3B0$+
MBTQ`+XLB_EO3K7D2JHD!"8M"%!&J[!M!^4\`"0M!02&+"@(-RD$!`4J,`0N+
M*D`NBR[^0M/A_5O3T7D1JDH!#(LA%`^J[!]!^2X`"@LB02*+J0$1RB(!`DJ,
M`0N+24`PB_#]0M/"_5O3#WH/JBD!#(M"%`ZJ["-!^5(`"0M!02&+*@(/RD$!
M`4J*`0N++4`MB\S]0M-!_EO3CGD.JJH!"HLA%!*J["=!^3``"@LB02*+Z0$.
MRB(!`DI-_D+3B0$+BTQ`,8L"_EO3B0$)BT(4$*JL>1*J\2M!^4T`"0M!02&+
MR@$,RD$!`4HQ`@N+*D`OBP_^0M.A_5O3\'D0JDH!$8LA%`VJ\2]!^2\`"@LB
M02*+B0$0RB(!`DHQ`@N+24`NBZ[]0M/B_5O3S7D-JBD!$8M"%`^J\3-!^4X`
M"0M!02&+"@(-RD$!`4HJ`@N++$`LB_']0M/!_5O3+WH/JHP!"HLA%`ZJZC=!
M^3$`#`LB02*+J0$/RBD!`DI"`0N+*D$PB]#]0M,I_EO3#GH.JDH!`HLI%1&J
MXCM!^3`!"@N!02&+[`$.RH$!`4HR_D+33``+BR)`+8L!_EO330`,BR$4$*I"
M>A&J[#]!^3$`#0M)02F+R@$"RDH!"4J)`0N+3$$OBP_^0M,J_EO3C`$)B^]Y
M$*I*%1&JZ4-!^5`!#`NA02&+30`/RJT!`4HA`0N+K4$NBPG^6],N_D+3K0$!
MB\YY$:HI%1"JX4=!^3$!#0N*02J+[`$.RHP!"DHJ``N+@D$BBR'^6]-"``J+
M(101JD(``0L!_D+3[$M!^2%X$*JJ02F+S0$!RDG\6]-C0"^+K0$*2BD5`JJ*
M`0N+*_Y"TTH!`XLI`0V+8WD1JD(`!@L(<4?Y(0`%"V0`!`O'`0<+)0$*"P4(
M`*D$!`&IXT]!^0(!0/EB``+*!Q``^8(``+7]>T"I_X,*D<`#7]:@``"P`&!'
M^0``/];]>[^IH0``L``0@-+]`P"1(2!'^2``/]8?&`#Y)F"$TB5QE=+$GYO2
MPXZ*T@(^G-*FZ*SRI?F]\D07L_)#!J+R0GJX\@84`*D$#`&I`GP"J1]X`+G]
M>\&HP`-?UA\@`]7]>[RI0GQ`D_T#`)'S4P&I%.``D?,#`:KU6P*I]0,`JO8#
M`JKW8P.I!8Q"J0!X0+FD#`(+OP`$ZV.4@YIB=$*+I(H"J6`$`#7?_@!QK08`
M5-8"`5'8?@93%P<`$?=J>M-W`A>+'R`#U6`&0*F`!@"I<P(!D6(.?:F"#@&I
MX`,5JF(.?JF"#@*I8@Y_J8(.`ZF@^_^7?P(7ZX'^_U36&AA+HP``L.$#%ZK@
M`Q2JPGY`DV/81OE@`#_6MGH`N?-30:GU6T*I]V-#J?U[Q*C``U_6HP``L!<(
M@%+W`@!+@,(@B]\"%VMCV$;YU]*7&OA^0)/B`QBJ8``_UJ!Z0+G@`@`+H'H`
MN1\``7&A_?]4U@(72W,"&(O@`Q6J?OO_E\O__Q?W`Q.JW___%Q\@`]4?(`/5
M_7N\J?T#`)'S4P&I\P,!JO0#`*KU6P*I=>(`D>$/@!+W&P#Y8!9`^78J0+EW
M,D"Y`"`#4]8*P%H"!``1]PK`6J'*(#B@PB*+7^``<0T*`%2C``"P`0B`4B(`
M`DL!`(!28SQ'^4)\0)-@`#_6X`,3JES[_Y=__@.I?_X$J7_^!:E_-@#Y=UH.
M*>`#$ZI5^_^780)`^>`#$ZHA_%C3@0(`.6$"0/DA_%#3@08`.6$"0/DA_$C3
M@0H`.6$"0/F!#@`Y809`^2'\6-.!$@`Y809`^2'\4-.!%@`Y809`^2'\2-.!
M&@`Y809`^8$>`#EA"D#Y(?Q8TX$B`#EA"D#Y(?Q0TX$F`#EA"D#Y(?Q(TX$J
M`#EA"D#Y@2X`.6$.0/DA_%C3@3(`.6$.0/DA_%#3@38`.6$.0/DA_$C3@3H`
M.6$.0/F!/@`Y81)`^2'\6-.!0@`Y81)`^2'\4-.!1@`Y81)`^2'\2-.!2@`Y
M81)`^8%.`#FA``"P\U-!J?5;0JGW&T#Y_7O$J#"H1_D``A_6HP``L`$'@%(B
M``)+`0"`4F,\1_E"?$"38``_UK?__Q<?(`/5_7N\J?T#`)'S4P&IM```L)3B
M+)'U6P*IM0``L+7"+)&4`A7+]@,`*O=C`ZGW`P&J^`,"JI3^0Y.@\?^7=`$`
MM!,`@-(?(`/5HWIS^.(#&*IS!@"1X0,7JN`#%BI@`#_6GP(3ZR'__U3S4T&I
M]5M"J?=C0ZG]>\2HP`-?UA\@`]7``U_6'R`#U1\@`]4?(`/5HP``T&,$0/F6
M\?\77R0#U?U[OZG]`P"1_7O!J,`#7]8!``(``````"]T;7``````+@``````
M``!005)?5$U01$E2````````5$U01$E2``!414U01$E2`%1%35``````5$U0
M``````!54T52`````%5315).04U%```````````E<R\E<P```"\`````````
M+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``
M````26YT97)N86QS.CI005(Z.D)/3U0`````97AE```````O<')O8R\E:2\E
M<P``````4$%27U1%35```````````%!!4E]04D]'3D%-10`````Z````````
M`"5S)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`````
M`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!0
M05)?0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10``````
M``!005)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@``
M``````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````
M4$%27T-,14%./0```````#$`````````3$1?3$E"4D%265]0051(`%-94U1%
M30``)3`R>`````!P87(M`````"5S)7,E<R5S```````````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F
M92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI
M"@```````%!!5$@`````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S
M```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````&```
M``````!P97)L`````#``````````4$%2.CI086-K97(Z.E9%4E-)3TX`````
M,2XP-30```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````+64````````M+0``````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@
M/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT
M("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*
M<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@
M=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR
M;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I
M;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@
M)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@
M?0I"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/
M3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@
M/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/
M(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?
M9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G
M+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]
M("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N
M86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M
M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R
M;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R!?1D@["FUY("1M86=I8U]P;W,@
M/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I>F4[(",@3D]413H@)&UA9VEC
M7W!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D;6%G
M:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`["G)E860@
M7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*
M:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@
M>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H
M=6YK7W-I>F4["GT*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N
M)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P
M<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IS965K(%]&2"P@)&UA9VEC7W!O
M<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@
M=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@
M(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D
M9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L
M;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E
M>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X
M="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M
M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@
M,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]
M/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD
M9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.
M0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE
M0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A
M(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*
M)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL
M96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB
M=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN
M9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"G5N;&5S<R`H
M)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@
M869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S
M="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@
M("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@
M*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@
M)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E
M(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM0
M05)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D
M(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E96YV
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q
M6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+
M7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T
M(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO
M861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD
M;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F
M:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D
M7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L
M97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@
M)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D
M:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F
M(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N
M86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK
M.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN
M+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D
M8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B
M.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N
M86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R
M:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R
M:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL
M"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@
M)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F:#L*)&-A
M8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@
M(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE
M("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*
M)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U
M-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T
M7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP
M(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE
M(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U
M<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@
M=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R
M<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB
M97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV
M97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;
M7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N
M86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X
M=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE
M;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@
M(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D
M97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE
M;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'
M5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U
M;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@
M6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H
M('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM
M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ
M9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T
M:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I
M.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U
M;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER
M92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*
M<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U
M:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B
M(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q
M.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL
M('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ
M=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE
M.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@
M*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E
M('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\
M?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%2
M7T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI
M('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K("1F:"P@+3$X+"`R
M.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@)&9H+"`D8G5F+"`T
M,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]
M8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*)&-T>"T^861D9FEL92@D
M9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE
M.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1S>7-[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]
M"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE
M+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A
M<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E
M;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/CIR87<G
M+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R:71E("(D=&5M<&YA;64B
M.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@
M)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E
M;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E
M='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%
M?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\
M/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L
M("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D
M<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q
M*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\
M)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D
M<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I
M<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E
M=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S
M+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO
M.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?
M:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G
M+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0
M?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S
M("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R
M*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?
M0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH```!P97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("```````1L#.P@!```@````+(;__SP&```<B?__
M(`$``$R)__\T`0``C(G__T@!``#<B?__;`$``.R)__^$`0``_(K___@!``#0
MC/__9`(``'R-__^,`@``H([__\`"````D/__``,``%R2__]4`P``[)+__W@#
M```\D___F`,``$R4___0`P``4)3__^0#``#<EO__4`0```R7__]D!```,)?_
M_W@$``!<G/__N`0``.R<___@!```')W__P`%``!<GO__1`4``-RF__^L!0``
MS*G___P%```LJ___=`8``+R[__^8!@``'+S__[@&``!,O?__\`8``/R^__\D
M!P``?+___U@'``",O___;`<``!```````````7I2``1X'@$;#!\`$````!@`
M``#TA___,``````````0````+````!"(__\\`````````"````!`````/(C_
M_T@`````00X@G02>`T*3`D[>W=,.`````!0```!D````:(C__P0`````````
M`````'````!\````8(C__P@!````00Y0G0J>"4*3")0'0I@#EP1#F0)$E@65
M!E?6U4'8UT'90][=T]0.`$$.4),(E`>5!I8%EP28`YD"G0J>"4_6U4'8UT'9
M0=[=T]0.`$$.4),(E`>="IX)0I<$F`.9`D+8UT'9:````/````#\B/__U`$`
M``!!#N`!G1R>&T*7%I@51Y09DQI$U--'WMW7V`X`00[@`9,:E!F7%I@5G1R>
M&T>6%Y480IH3F10"1`K4TT'6U4':V4$+2=/4U=;9VD*4&9,:0I87E1A!FA.9
M%```)````%P!``!DBO__K`````!!#K`!G1:>%4.3%)0360K>W=/4#@!!"S``
M``"$`0``Z(K__R0!````00X@G02>`T23`F$*WMW3#@!""U8*WMW3#@!!"TC>
MW=,.```\````N`$``-B+__]@`0```$(.T"!"G8H$GHD$0Y.(!)2'!$*5A@26
MA01$EX0$F(,$;PK=WM?8U=;3U`X`00L`4````/@!``#XC/__6`(```!!#G"=
M#IX-0I,,E`M#E0J6"4*7")@'2YD&F@4"0`K>W=G:U]C5UM/4#@!!"TB;!&,*
MVT$+2]M"FP1#VT*;!$/;````(````$P"````C___C`````!!#B"=!)X#0I,"
ME`%8WMW3U`X`'````'`"``!LC___2`````!!#A"=`IX!2M[=#@`````T````
MD`(``)R/__\(`0```$(.T$!"G8H(GHD(0I.(")2'"$.5A@B6A0AU"MW>U=;3
MU`X`00L``!````#(`@``=)#__P0`````````:````-P"``!DD/__B`(```!"
M#O`A09V>!)Z=!$*9E@2:E01#DYP$E)L$0Y6:!):9!%X*W=[9VM76T]0.`$$+
M0IB7!)>8!%.;E`1_"MC70=M!"UG8UT';09>8!)B7!$'8UT.8EP27F`1"FY0$
M$````$@#``"$DO__*``````````0````7`,``*"2__\D`````````#P```!P
M`P``L)+__R@%````00Z0`9T2GA%$DQ"4#T25#I8-19<,F`N9"IH)`R`!"M[=
MV=K7V-76T]0.`$$+```D````L`,``)R7__^0`````$$.,)T&G@5"DP24`U`*
MWMW3U`X`00L`'````-@#```$F/__,`````!!#A"=`IX!2M[=#@````!`````
M^`,``!28__]``0```$$.4)T*G@E"E0:6!4.7!)@#1),(E`=5"M[=U]C5UM/4
M#@!!"TT*WMW7V-76T]0.`$$+`&0````\!```$)G__X`(````0@[`@P)"G;8@
MGK4@0INL()RK($.5LB"6L2!)D[0@E+,@E[`@F*\@0YFN()JM(`*<"MW>V]S9
MVM?8U=;3U`X`00L"R0K=WMO<V=K7V-76T]0.`$$+````3````*0$```HH?__
M[`(```!!#G"=#IX-0I,,E`M#E0J6"4*9!IH%0I<(F`<"0YL$3-MS"M[=V=K7
MV-76T]0.`$$+2IL$3-M+"IL$0@M"FP0\````]`0``,BC__]@`0```$$.4)T*
MG@E"E0:6!4.3")0'0I<$8@K>W=?5UM/4#@!!"U0*WMW7U=;3U`X`00L`-```
M`#0%``#H?___E`(```!!#G"=#IX-0I,,E`M$E0J6"9<(`G`*WMW7U=;3U`X`
M00L````````@````;`4``+"D__^0$````$$.H`5&G52>4P,9!`K=W@X`00L<
M````D`4``!RU__]<`````$$.$)T"G@%5WMT.`````#0```"P!0``7+7__R@!
M````00Y`G0B>!T.3!I0%0Y4$E@-#EP*8`6D*WMW7V-76T]0.`$$+````,```
M`.@%``!4MO__K`$```!!#D"=")X'0I,&E`5#E026`T.7`@)8"M[=U]76T]0.
M`$(+`#`````<!@``T+?__WP`````00Y`G0B>!T*3!I0%0Y4$E@-%EP*8`5/>
MW=?8U=;3U`X````0````4`8``!RX__\$`````````!````!D!@``&+C__PP`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````\"``````
M``"@(`````````$`````````$0,````````!`````````!P#`````````0``
M```````L`P````````$`````````-@,````````/`````````,$$````````
M#`````````#('`````````T`````````K%8````````9`````````#"K`0``
M````&P`````````(`````````!H`````````.*L!```````<``````````@`
M````````]?[_;P````"8`@````````4`````````*`X````````&````````
M`#@$````````"@````````#D!`````````L`````````&``````````5````
M`````````````````P````````!PK0$```````(`````````8``````````4
M``````````<`````````%P````````!H'`````````<`````````0!0`````
M```(`````````"@(````````"0`````````8`````````!@`````````````
M``````#[__]O``````$```@`````_O__;P````#@$P```````/___V\`````
M`P````````#P__]O``````P3````````^?__;P`````4````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````X!P```````#@'````````.`<````````X!P```````!`JP$`
M````````````````D%8`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````P4P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````05@``
M````````````````````````````````````````````````````````````
M`````````*!6````````````````````````````````````````````````
M````````````````````````8%0``````````````````$`=````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````T%(`````````````````````````
M``````````````````````````BP`0``````_____P````#(5@```````-!6
M``````````````````#85@```````.A6````````\%8```````#X5@``````
M``!7```````````````````(5P```````!!7``````````````````"(6@``
M`````$=#0SH@*$=.52D@,3`N,BXP`$=#0SH@*&-R;W-S=&]O;"U.1R`Q+C(S
M+C`N-#$X+60U.3`I(#$P+C(N,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN
M`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M
M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA
M;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````
M````````````````````````````````````````````````````````````
M``````L````!`````@`````````X`@```````#@"````````&P``````````
M``````````$````````````````````3````!P````(`````````5`(`````
M``!4`@```````"0````````````````````$````````````````````)@``
M``<````"`````````'@"````````>`(````````@````````````````````
M!````````````````````#0```#V__]O`@````````"8`@```````)@"````
M````H`$````````%``````````@````````````````````^````"P````(`
M````````.`0````````X!````````/`)````````!@````,````(````````
M`!@`````````1@````,````"`````````"@.````````*`X```````#D!```
M`````````````````0```````````````````$X```#___]O`@`````````,
M$P````````P3````````U``````````%``````````(``````````@``````
M``!;````_O__;P(`````````X!,```````#@$P```````&``````````!@``
M``,````(````````````````````:@````0````"`````````$`4````````
M0!0````````H"`````````4`````````"``````````8`````````'0````$
M````0@````````!H'````````&@<````````8``````````%````%0````@`
M````````&`````````!^`````0````8`````````R!P```````#('```````
M`!@````````````````````$````````````````````>0````$````&````
M`````.`<````````X!P```````!@````````````````````$``````````0
M`````````(0````!````!@````````!`'0```````$`=````````;#D`````
M`````````````!````````````````````"*`````0````8`````````K%8`
M``````"L5@```````!0````````````````````$````````````````````
MD`````$````"`````````,!6````````P%8```````!20```````````````
M````"````````````````````)@````!`````@`````````4EP```````!27
M````````#`$```````````````````0```````````````````"F`````0``
M``(`````````()@````````@F````````'@&```````````````````(````
M````````````````L`````X````#`````````#"K`0``````,*L````````(
M````````````````````"``````````(`````````+P````/`````P``````
M```XJP$``````#BK````````"`````````````````````@`````````"```
M``````#(````!@````,`````````0*L!``````!`JP```````#`"````````
M!@`````````(`````````!``````````T0````$````#`````````'"M`0``
M````<*T```````"0`@``````````````````"``````````(`````````-8`
M```!`````P``````````L`$```````"P````````@```````````````````
M``@```````````````````#<````"`````,`````````@+`!``````"`L```
M`````"@0```````````````````(````````````````````X0````$````P
M````````````````````@+`````````]`````````````````````0``````
M```!``````````$````#`````````````````````````+VP````````Z@``
=``````````````````$`````````````````````
